from setuptools import setup

setup(name='oleg',
      version='0.1',
      description='oleg package',
      packages=['oleg'],
      author_email='aleksandrparnuk7@gmail.com',
      zip_safe=False)
